@@ -5,7 +5,7 @@
 #
 class CommentStreamA:
 	def __init__(self):
-		self.data = None
+		self.data:str = None
 
 	def to_bytes(self):
 		return self.data.encode('ascii')
